==> apache-camel-4.3.0-src.zip: apache-camel-4.3.0/core/camel-core-reifier/src/main/java/org/apache/camel/reifier/language/JavaExpressionReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier.language;

import org.apache.camel.CamelContext;
import org.apache.camel.model.language.ExpressionDefinition;
import org.apache.camel.model.language.JavaExpression;

public class JavaExpressionReifier extends TypedExpressionReifier<JavaExpression> {

    public JavaExpressionReifier(CamelContext camelContext, ExpressionDefinition definition) {
        super(camelContext, definition);
    }

    @Override
    protected Object[] createProperties() {
        Object[] properties = new Object[3];
        properties[0] = parseBoolean(definition.getPreCompile());
        properties[1] = definition.getResultType();
        properties[2] = parseBoolean(definition.getSingleQuotes());
        return properties;
    }

    @Override
    public boolean isResolveOptionalExternalScriptEnabled() {
        // we handle this in camel-joor (joor is used for compiling java source at runtime)
        return false;
    }

}

==> apache-camel-4.14.1-src.zip: apache-camel-4.14.1/core/camel-core-reifier/src/main/java/org/apache/camel/reifier/language/JavaExpressionReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier.language;

import org.apache.camel.CamelContext;
import org.apache.camel.model.language.ExpressionDefinition;
import org.apache.camel.model.language.JavaExpression;

public class JavaExpressionReifier extends TypedExpressionReifier<JavaExpression> {

    public JavaExpressionReifier(CamelContext camelContext, ExpressionDefinition definition) {
        super(camelContext, definition);
    }

    @Override
    protected Object[] createProperties() {
        Object[] properties = new Object[3];
        properties[0] = asResultType();
        properties[1] = parseBoolean(definition.getPreCompile());
        properties[2] = parseBoolean(definition.getSingleQuotes());
        return properties;
    }

    @Override
    public boolean isResolveOptionalExternalScriptEnabled() {
        // we handle this in camel-joor (joor is used for compiling java source at runtime)
        return false;
    }

}
